PaletteIndex

Struct PaletteIndex 

pub struct PaletteIndex(/* private fields */);
Available on crate feature cgb only.
Color palette index (BCPS / OCPS).

BitFieldAccessMeaning
7auto_incrementR/WAuto-increment the address after each data-port write.
6Unused.
5-0addressR/WByte offset into palette memory reached through the data port.

Implementations

Source

impl PaletteIndex

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u8) -> Self

Convert from bits.

pub const fn into_bits(self) -> u8

Convert into bits.

pub const fn address(&self) -> u8

Byte offset into palette memory reached through the data port.

Bits: 0..6

pub const fn with_address_checked(self, value: u8) -> Result<Self, ()>

Byte offset into palette memory reached through the data port.

Bits: 0..6

pub const fn with_address(self, value: u8) -> Self

Byte offset into palette memory reached through the data port.

Bits: 0..6

pub const fn set_address(&mut self, value: u8)

Byte offset into palette memory reached through the data port.

Bits: 0..6

pub const fn set_address_checked(&mut self, value: u8) -> Result<(), ()>

Byte offset into palette memory reached through the data port.

Bits: 0..6

pub const fn auto_increment(&self) -> bool

Auto-increment the address after each write to the data port.

Bits: 7..8

pub const fn with_auto_increment_checked(self, value: bool) -> Result<Self, ()>

Auto-increment the address after each write to the data port.

Bits: 7..8

pub const fn with_auto_increment(self, value: bool) -> Self

Auto-increment the address after each write to the data port.

Bits: 7..8

pub const fn set_auto_increment(&mut self, value: bool)

Auto-increment the address after each write to the data port.

Bits: 7..8

pub const fn set_auto_increment_checked( &mut self, value: bool, ) -> Result<(), ()>

Auto-increment the address after each write to the data port.

Bits: 7..8