pub struct PaletteIndex(/* private fields */);Available on crate feature
cgb only.Expand description
Color palette index (BCPS / OCPS).
| Bit | Field | Access | Meaning |
|---|---|---|---|
| 7 | auto_increment | R/W | Auto-increment the address after each data-port write. |
| 6 | — | Unused. | |
| 5-0 | address | R/W | Byte offset into palette memory reached through the data port. |
Implementations
Sourceimpl PaletteIndex
impl PaletteIndex
Sourcepub const fn address(&self) -> u8
pub const fn address(&self) -> u8
Byte offset into palette memory reached through the data port.
Bits: 0..6
Sourcepub const fn with_address_checked(self, value: u8) -> Result<Self, ()>
pub const fn with_address_checked(self, value: u8) -> Result<Self, ()>
Byte offset into palette memory reached through the data port.
Bits: 0..6
Sourcepub const fn with_address(self, value: u8) -> Self
pub const fn with_address(self, value: u8) -> Self
Byte offset into palette memory reached through the data port.
Bits: 0..6
Sourcepub const fn set_address(&mut self, value: u8)
pub const fn set_address(&mut self, value: u8)
Byte offset into palette memory reached through the data port.
Bits: 0..6
Sourcepub const fn set_address_checked(&mut self, value: u8) -> Result<(), ()>
pub const fn set_address_checked(&mut self, value: u8) -> Result<(), ()>
Byte offset into palette memory reached through the data port.
Bits: 0..6
Sourcepub const fn auto_increment(&self) -> bool
pub const fn auto_increment(&self) -> bool
Auto-increment the address after each write to the data port.
Bits: 7..8
Sourcepub const fn with_auto_increment_checked(self, value: bool) -> Result<Self, ()>
pub const fn with_auto_increment_checked(self, value: bool) -> Result<Self, ()>
Auto-increment the address after each write to the data port.
Bits: 7..8
Sourcepub const fn with_auto_increment(self, value: bool) -> Self
pub const fn with_auto_increment(self, value: bool) -> Self
Auto-increment the address after each write to the data port.
Bits: 7..8
Sourcepub const fn set_auto_increment(&mut self, value: bool)
pub const fn set_auto_increment(&mut self, value: bool)
Auto-increment the address after each write to the data port.
Bits: 7..8